@@ -1,7 +1,7 @@
 /**********
 This library is free software; you can redistribute it and/or modify it under
 the terms of the GNU Lesser General Public License as published by the
-Free Software Foundation; either version 2.1 of the License, or (at your
+Free Software Foundation; either version 3 of the License, or (at your
 option) any later version. (See <http://www.gnu.org/copyleft/lesser.html>.)
 
 This library is distributed in the hope that it will be useful, but WITHOUT
@@ -14,7 +14,7 @@ along with this library; if not, write to the Free Software Foundation, Inc.,
 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 **********/
 // "liveMedia"
-// Copyright (c) 1996-2008 Live Networks, Inc.  All rights reserved.
+// Copyright (c) 1996-2017 Live Networks, Inc.  All rights reserved.
 // A source object for AMR audio sources
 // Implementation
 
@@ -29,6 +29,10 @@ AMRAudioSource::AMRAudioSource(UsageEnvironment& env,
 AMRAudioSource::~AMRAudioSource() {
 }
 
+char const* AMRAudioSource::MIMEtype() const {
+  return "audio/AMR";
+}
+
 Boolean AMRAudioSource::isAMRAudioSource() const {
   return True;
 }
